@@ -29,6 +29,8 @@
 (use-modules (ice-9 regex))
 
 (define enable-colors-flag "yes")
+(define ignored-msg-pattern-list '())
+
 
 (define color-list 
   '(("yellow" . "33")
@@ -44,6 +46,28 @@
     '()
     (define auto-color-list '()))
 
+(define (ignore-message! pattern)
+  "ignore messages matching the pattern"
+  (set! ignored-msg-pattern-list
+	(cons pattern ignored-msg-pattern-list)))
+
+(define (ignored-message? message)
+  "tell if this message has to be ignored"
+  (letrec
+      ((local-ignored-message? 
+	(lambda (pattern-list message)
+	  (if (= (length pattern-list) 0)
+	      #f
+	      (if (= (length pattern-list) 1)
+		  (regexp-match? (string-match
+				  (car pattern-list) message))
+		  (if (regexp-match? (string-match
+				      (car pattern-list) message))
+		  #t
+		  (local-ignored-message? 
+		   (cdr pattern-list) message)))))))
+       (local-ignored-message? ignored-msg-pattern-list message)))
+
 
 (if (defined? 'default-color)
     '()
@@ -86,26 +110,36 @@
 
 (define (append-color timestamp from msg)
   "append color"
-  (if (equal? enable-colors-flag "yes")
-      (begin
-	(if (get-buddy-color from)
-	    (begin
-	      (ft-display 
-	       (string-append
-                (if (> (string-length timestamp) 0)
-                    (color-message (string-append "[" timestamp "] ")
-                                   (get-buddy-color from))
-                    "")
-		(color-message from (get-buddy-color from))
-		(color-message " -> " (get-buddy-color from))
-		(color-message msg (get-buddy-color from))))
-	      (ft-hook-return))))))
+  (if (ignored-message? msg)
+      (ft-hook-return)
+      (if (equal? enable-colors-flag "yes")
+	  (begin
+	    (if (get-buddy-color from)
+		(begin
+		  (ft-display 
+		   (string-append
+		    (if (> (string-length timestamp) 0)
+			(color-message (string-append "[" timestamp "] ")
+				       (get-buddy-color from))
+			"")
+		    (color-message from (get-buddy-color from))
+		    (color-message " -> " (get-buddy-color from))
+		    (color-message msg (get-buddy-color from))))
+		  (ft-hook-return)))))))
 
 (add-hook! ft-message-receive-hook append-color)
 
-(define (enable-colors)
-  (set! enable-colors-flag "yes"))
+(define (/color-enable args)
+  " enable's color "
+  (set! enable-colors-flag "yes")
+  (ft-display (_ " BUDDY coloring enabled ")))
 
-(define (disable-colors)
-  (set! enable-colors-flag "no"))
+(add-command! /color-enable "/color-enable" "color-enable" "Enables buddy coloring")
+
+(define (/color-disable args)
+  " disable's color "
+  (set! enable-colors-flag "no")
+  (ft-display (_ " BUDDY coloring disabled ")))
+
+(add-command! /color-disable "/color-disable" "color-disable" "Disables buddy coloring")
 
