@@ -19,15 +19,20 @@
 
 (define (/add  args)
   (if (= (string-length args) 0)
-      (ft-display "Incomplete syntax")
-      (ft-add-buddy! args)))
+      (ft-display (_ "Incomplete syntax"))
+      (begin
+	(ft-add-buddy! (sans-surrounding-whitespace args))
+	(ft-subscription-allow (sans-surrounding-whitespace args)))))
 
 (add-command! /add "/add" "/add [USER@SERVER]" "add new buddy to list")
 
 (define (/remove args)
   (if (= (string-length args) 0)
-      (ft-display "Incomplete syntax")
-      (ft-remove-buddy! args)))
+      (ft-display (_ "Incomplete syntax"))
+      (begin
+	(ft-remove-buddy! (sans-surrounding-whitespace args))
+	(ft-subscription-deny (sans-surrounding-whitespace args)))))
+
 (add-command! /remove "/remove" "/remove [USER@SERVER]" "remove buddy from list")
 
 (define (pretty-print-show-msg msg)
@@ -55,24 +60,32 @@
                                          (if (> (string-length status-msg) 0)
                                              (string-append " (" status-msg ")")
                                              "")))
-                    (ft-display (string-append "   " jid (if (> (string-length nickname) 0) 
+                    (and (string=? args "all") (ft-display (string-append "   " jid (if (> (string-length nickname) 0) 
 							     (string-append " (" nickname ") ") 
-							     " "))))))
+							     " ")))))))
             (ft-get-roster-list)))
 
 (add-command! /who "/who" "/who" "display buddy list")
 
+(define (/whoami args)
+  (ft-display (string-append (_ "Jabber ID: ") (ft-get-jid) "\n"
+			     (_ "Jabber Server: ") (ft-get-server) "\n"
+			     (_ "Status: ") (ft-get-status-msg))))
+
+(add-command! /whoami "/whoami" "/whoami" "display who is this")
+(add-command! /whoami "/whomomlikes" "/whomomlikes" "same as /whoami")
+
 (define (/allow args)
   (if (= (string-length args) 0)
-      (ft-display "Incomplete syntax")
-      (ft-subscription-allow args)))
+      (ft-display (_ "Incomplete syntax"))
+      (ft-subscription-allow (sans-surrounding-whitespace args))))
 
 (add-command! /allow "/allow" "/allow [USER@SERVER]" "Allow buddy to see your status")
 
 (define (/deny args)
   (if (= (string-length args) 0)
-      (ft-display "Incomplete syntax")
-      (ft-subscription-deny args)))
+      (ft-display (_ "Incomplete syntax"))
+      (ft-subscription-deny (sans-surrounding-whitespace args))))
 (add-command! /deny "/deny" "/deny [USER@SERVER]" "Deny buddy permission to see your status")
 
 (define (presence-recv jid online nickname show-msg status-msg)
@@ -89,8 +102,8 @@
               ; using old-jid is a simple way to strip away the resource part ;)
               (ft-display (string-append old-jid " -> " 
                                          (if online  
-                                             "Online" 
-                                             "Logoff")
+                                             (_ "Online") 
+                                             (_ "Logoff"))
                                          (if (> (string-length show-msg) 0)
                                              (string-append " [" (pretty-print-show-msg show-msg) "]")
                                              "")
@@ -100,7 +113,8 @@
 (add-hook! ft-presence-receive-hook presence-recv)
 
 (define (subscribe-recv jid)
-  (ft-display (string-append "[Buddy request recieved from " jid " use /allow or /deny]"))
-  (ft-display (string-append "[Use /add " jid " to add him/her to your buddy list]")))
+  (ft-display (string-append (_ "[Buddy request recieved from ") jid (_ " use /allow or /deny]")))
+  (ft-display (string-append (_ "[Use /add ") jid (_ " to add him/her to your buddy list]"))))
+
+(add-hook! ft-subscribe-receive-hook subscribe-recv)
 
-(add-hook! ft-subscribe-receive-hook subscribe-recv)
\ No newline at end of file
