@@ -20,9 +20,9 @@
 
 (define (/version args)
   "display version info"
-  (display (string-append "freetalk (FreeTalk) " (ft-version) "\n"
-			  "Copyright (C) 2005 FreeTalk Core Team.\n"
-			  "This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n")))
+  (display (string-append (_ "freetalk (FreeTalk) ") (ft-version) "\n"
+			  (_ "Copyright (C) 2005 FreeTalk Core Team.\n")
+			  (_ "This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"))))
 
 (add-command! /version "/version" "/version" "display freetalk version information")
 
@@ -63,16 +63,6 @@
 		    (any->symbol (car li))))
 		  (list->strlist (cdr li))))))
 
-;;(define (send-message-to-group group message)
-;;  "send message to group"
-;;  (for-each (lambda (buddy)
-;;	      (begin
-;;		(fh-send-message-no-hook buddy message)))
-;;	    ;; since yahoo dont allow message flooding, solve this
-;;	    ;; you need to sleep for every n number of user
-;;	    ;; (usleep 99999)))
-;;	    (list->strlist group)))
-
 (define (local-date-time)
   (string-append
                  (strftime "%F" (localtime (current-time)))
