@@ -1,5 +1,6 @@
 /*
-  (C) 2005 Anand Avati <avati@zresearch.com>
+  Author: Anand Avati <avati@zresearch.com>
+  (C) 2005,2006 Freetalk core team
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -29,6 +30,8 @@ extern SCM ex_subscribe_receive_hook;
 extern SCM ex_disconnect_hook;
 extern SCM ex_command_hook;
 extern SCM ex_login_hook;
+extern SCM ex_quit_hook;
+extern SCM ex_notify_file_hook;
 
 int get_hook_return (void);
 void set_hook_return (int hook_return_value);
