@@ -1,5 +1,6 @@
 /*
-  (C) 2005 Vikas Gorur <vikasgp@gmail.com>
+  Author: Vikas Gorur <vikas@80x25.org>
+  (C) 2005,2006 Freetalk core team
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -20,14 +21,20 @@
 #ifndef __FREETALK_H__
 #define __FREETALK_H__
 
+#include <libintl.h>
 #include <loudmouth/loudmouth.h>
 #include "util.h"
+#include "file_transfer.h"
 
 #define FT_GLOBAL_EXT_DIR   DATADIR "/" PACKAGE_NAME "/extensions"
 #define FT_LOCAL_EXT_DIR    "." PACKAGE_NAME "/extensions" /* relative to $HOME */
 #define FT_CONFIG_SCM        "." PACKAGE_NAME "/" PACKAGE_NAME ".scm"
 
-enum foo {
+#define _(String) gettext (String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
+enum ft_conn_state {
   FT_DEAD = 0,
   FT_CONN,
   FT_AUTH
@@ -48,11 +55,13 @@ typedef struct {
   unsigned short port;
   char daemon;
   char async_printf;
-  enum foo conn_state;
+  enum ft_conn_state conn_state;
   char *status_msg;
   GSList *roster;
   char *script;
   char *config_dir;
+  GSList *f_state; /* file transfer states - linked list */
+  char *download_dirname; /* default directory where all files xfered go */
 } ft_state;
 
 extern ft_state state;
