@@ -1,5 +1,6 @@
 /*
-  (C) 2005 Anand Avati <avati@zresearch.com>
+  Author: Anand Avati <avati@zresearch.com>
+  (C) 2005,2006 Freetalk core team
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -94,4 +95,15 @@ SCM ex_get_config_dir (void);
 SCM ex_subscription_allow (SCM jid);
 SCM ex_subscription_deny (SCM jid);
 
+SCM ex_beep (SCM freq, SCM msec);
+
+SCM ex_give_repl (void);
+
+SCM ex_quit (SCM exit_code);
+
+SCM ex_send_file (SCM reciever, SCM file_name);
+SCM ex_set_allow_file (SCM cookie, SCM file_name);
+
+SCM ex_change_password (SCM newpass);
+
 #endif /* __PRIMITIVES_H__ */
