@@ -1,6 +1,7 @@
 /*
-  (C) 2005 Vikas Gorur <vikasgp@gmail.com>
-
+  Author: Vikas Gorur <vikas@80x25.org>
+  (C) 2005,2006 Freetalk core team
+  
   callbacks.c: Callback functions
   
   This program is free software; you can redistribute it and/or
@@ -18,7 +19,8 @@
   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301 USA
 */
-
+#ifndef __ROSTER_H__
+#define __ROSTER_H__
 #include <glib.h>
 
 /*
@@ -44,6 +46,7 @@ typedef struct
   char *nickname;
   char *show_msg;
   char *status_msg;
+  char *resource; /* resource is client software name */
 } FtRosterItem;
 
 void ft_roster_init (LmConnection *conn);
@@ -55,7 +58,10 @@ void ft_roster_add (char *jid, char *nickname);
 void ft_roster_remove (char *jid);
 
 GSList *ft_roster_get (void);
+void ft_roster_retrieve (LmConnection *conn);
 void ft_roster_flush ();
 
 FtRosterItem *ft_roster_lookup (const char *jid);
 void ft_roster_retrieve (LmConnection *conn);
+
+#endif /* __ROSTER_H__ */
